@@ -4,7 +4,7 @@ import click
 
 from src.config import global_config, config_manager
 from src.config.global_config import compile_ip, compile_host_mame
-from src.local import http_server, pc_info, net_manager
+from src.local import http_server, pc_info, net_manager, pc_test
 from src.script import script_manager
 from src.server import server_config
 
@@ -37,8 +37,8 @@ def print_version(ctx, param, value):
     作者:ming 
     仅适用linux 其他平台兼容性不做保证
     启用自动补全:
-    bash: eval "$(_M_COMPLETE=source m)"
-    zsh: eval "$(_M_COMPLETE=source_zsh m)"
+    bash:在.bashrc末尾添加 eval "$(_M_COMPLETE=source m)"
+    zsh:在.zshrc末尾添加 eval "$(_M_COMPLETE=source_zsh m)"
     jiuming-tools Version {}""".format(global_config.version)
     click.echo(version_info)
     ctx.exit()
@@ -112,10 +112,22 @@ def local_tmp_http(d, port, host):
 @local.command('socket-test', help='测试服务器是否可以打开socket')
 @click.option('--host', '-h', type=str, prompt='请输入服务器地址', callback=validate_ip_or_host_name_type, help='服务器地址')
 @click.option('--port', '-p', type=int, default=80, help='探测端口号(默认为80)')
-def net_test(host, port):
+def socket_test(host, port):
     net_manager.net_test(host, port)
 
 
+@local.command('test-disk', help='测试服务器磁盘性能')
+@click.option('--size', '-s', type=int, default=2, help='测试磁盘数据大小，单位GB，默认2GB')
+def test_disk(size):
+    pc_test.testDisk(size)
+
+
+@local.command('test-net', help='测试服务器网络速度')
+@click.option('--threads', '-t', type=int, default=None, help='线程数,默认为speettest的默认参数')
+def test_network(threads):
+    pc_test.testNetwork(threads)
+
+
 # ----------------------------------- tools config manager  -----------------------------------------------------------
 
 config_remark = """
